==> ngwshare-0.2.3.tar.gz: ngwshare-0.2.3/ngwshare/constants.py <==
__author__ = 'wangjian'


# ODBC_D = '{SQL Server}'
ODBC_D = '/opt/microsoft/msodbcsql/lib64/libmsodbcsql-13.1.so.9.2'

# -----------------------------------------------------------------------------------------
# HOST = 'stq.niuguwang.com'  # 外网

# HOST = '192.168.3.212:8080'  # 测试
HOST = '192.168.8.104:80'  # 生产
# HOST = '127.0.0.1:5001'


PRE = 'http://'
# PRE = 'https://s'
# PRE = 'https://tests'

# -----------------------------------------------------------------------------------------
# 主要获取innercode信息

# # ubuntu
# MYSQL_HOST = '192.168.157.129'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'ngw_strategy'
# MYSQL_USER = 'root'
# MYSQL_PASSWORD = 'mysql'

# 生产 8.104
MYSQL_HOST = 'stq.mysql.ngw.zw.in'
MYSQL_PORT = 3306
MYSQL_DATABASE = 'ngw_strategy'
MYSQL_USER = 'tjlh'
MYSQL_PASSWORD = 'tjXx^Egw3NdnLK'

# # yy
# MYSQL_HOST = 'localhost'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'ngw_strategy'
# MYSQL_USER = 'root'
# MYSQL_PASSWORD = 'ng123456'

# # 本地
# MYSQL_HOST = 'localhost'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'ngw_strategy'
# MYSQL_USER = 'root'
# MYSQL_PASSWORD = 'mysql'

# # 测试
# MYSQL_HOST = '192.168.3.215'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'ngw_strategy'
# MYSQL_USER = 'tjlh'
# MYSQL_PASSWORD = 'L*P30wk|dvhdR'

# -----------------------------------------------------------------------------------------
# 主要获取北向信息 胡灵智

# # 测试
# MYSQL_2_HOST = '192.168.3.212'
# MYSQL_2_PORT = 3306
# MYSQL_2_DATABASE = 'stq_taoquant'
# MYSQL_2_USER = 'lhpt'
# MYSQL_2_PASSWORD = 'z5^F2dj$vb6thkj'

# 生产 8.104
MYSQL_2_HOST = 'stq.mysql.ngw.zw.in'
MYSQL_2_PORT = 3306
MYSQL_2_DATABASE = 'stq_taoquant'
MYSQL_2_USER = 'tjlh'
MYSQL_2_PASSWORD = 'tjXx^Egw3NdnLK'

# -----------------------------------------------------------------------------------------
# # 主要获取板块信息、基金数据

# # 测试
# SQL_SERVER_HOST = '192.168.3.112'
# SQL_SERVER_DATABASE = 'DB_INFORMATION'
# SQL_SERVER_USER = 'sa'
# SQL_SERVER_PASSWORD = 'taotao778899!'

# 生产
SQL_SERVER_HOST = '192.168.2.55'
SQL_SERVER_DATABASE = 'DB_INFORMATION'
SQL_SERVER_USER = 'sa'
SQL_SERVER_PASSWORD = 'taotao778899!'

# -----------------------------------------------------------------------------------------
# 主要插入DK DT

# # 测试
# SQL_SERVER_2_HOST = '192.168.3.112'
# SQL_SERVER_2_DATABASE = 'DB_IQNgwStrategy'
# SQL_SERVER_2_USER = 'sa'
# SQL_SERVER_2_PASSWORD = 'taotao778899!'

# 生产
SQL_SERVER_2_HOST = 'ngwstrategy.mssql.niuguwang'
SQL_SERVER_2_DATABASE = 'DB_IQNgwStrategy'
SQL_SERVER_2_USER = 'sa'
SQL_SERVER_2_PASSWORD = 'taotao778899!'

# -----------------------------------------------------------------------------------------

==> ngwshare-0.2.4.tar.gz: ngwshare-0.2.4/ngwshare/constants.py <==
__author__ = 'wangjian'


# ODBC_D = '{SQL Server}'
ODBC_D = '/opt/microsoft/msodbcsql/lib64/libmsodbcsql-13.1.so.9.2'

# -----------------------------------------------------------------------------------------
# HOST = 'stq.niuguwang.com'  # 外网

# HOST = 'http://192.168.3.212:8080/api'  # 测试
# HOST = 'http://192.168.8.104:80/api'  # 生产
HOST = 'https://stq.niuguwang.com/jydata'  # 生产

# PRE = 'http://'
PRE = 'https://s'
# PRE = 'https://tests'

# -----------------------------------------------------------------------------------------
# 主要获取innercode信息

# # ubuntu
# MYSQL_HOST = '192.168.157.129'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'ngw_strategy'
# MYSQL_USER = 'root'
# MYSQL_PASSWORD = 'mysql'

# 生产 8.104
MYSQL_HOST = 'stq.mysql.ngw.zw.in'
MYSQL_PORT = 3306
MYSQL_DATABASE = 'ngw_strategy'
MYSQL_USER = 'tjlh'
MYSQL_PASSWORD = 'tjXx^Egw3NdnLK'

# # yy
# MYSQL_HOST = 'localhost'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'ngw_strategy'
# MYSQL_USER = 'root'
# MYSQL_PASSWORD = 'ng123456'

# # 本地
# MYSQL_HOST = 'localhost'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'ngw_strategy'
# MYSQL_USER = 'root'
# MYSQL_PASSWORD = 'mysql'

# # 测试
# MYSQL_HOST = '192.168.3.215'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'ngw_strategy'
# MYSQL_USER = 'tjlh'
# MYSQL_PASSWORD = 'L*P30wk|dvhdR'

# -----------------------------------------------------------------------------------------
# 主要获取北向信息 胡灵智

# # 测试
# MYSQL_2_HOST = '192.168.3.212'
# MYSQL_2_PORT = 3306
# MYSQL_2_DATABASE = 'stq_taoquant'
# MYSQL_2_USER = 'lhpt'
# MYSQL_2_PASSWORD = 'z5^F2dj$vb6thkj'

# 生产 8.104
MYSQL_2_HOST = 'stq.mysql.ngw.zw.in'
MYSQL_2_PORT = 3306
MYSQL_2_DATABASE = 'stq_taoquant'
MYSQL_2_USER = 'tjlh'
MYSQL_2_PASSWORD = 'tjXx^Egw3NdnLK'

# -----------------------------------------------------------------------------------------
# # 主要获取板块信息、基金数据

# # 测试
# SQL_SERVER_HOST = '192.168.3.112'
# SQL_SERVER_DATABASE = 'DB_INFORMATION'
# SQL_SERVER_USER = 'sa'
# SQL_SERVER_PASSWORD = 'taotao778899!'

# 生产
SQL_SERVER_HOST = '192.168.2.55'
SQL_SERVER_DATABASE = 'DB_INFORMATION'
SQL_SERVER_USER = 'sa'
SQL_SERVER_PASSWORD = 'taotao778899!'

# -----------------------------------------------------------------------------------------
# 主要插入DK DT

# # 测试
# SQL_SERVER_2_HOST = '192.168.3.112'
# SQL_SERVER_2_DATABASE = 'DB_IQNgwStrategy'
# SQL_SERVER_2_USER = 'sa'
# SQL_SERVER_2_PASSWORD = 'taotao778899!'

# 生产
SQL_SERVER_2_HOST = 'ngwstrategy.mssql.niuguwang'
SQL_SERVER_2_DATABASE = 'DB_IQNgwStrategy'
SQL_SERVER_2_USER = 'sa'
SQL_SERVER_2_PASSWORD = 'taotao778899!'

# -----------------------------------------------------------------------------------------
